import {
  withLayoutChildProps,
  withMarginProps,
  withPositioningProps
} from "./chunk.TWXTKG4B.js";
import {
  watch
} from "./chunk.TYGMNHNO.js";
import {
  tokens
} from "./chunk.FI4AQLJC.js";
import {
  GdsElement
} from "./chunk.TMEWQZER.js";
import {
  gdsCustomElement,
  html
} from "./chunk.QK3R23GV.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "./chunk.SEHSDSX2.js";

// libs/core/src/components/spinner/gds-spinner.ts
import { localized, msg } from "@lit/localize";
import { property, state } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";

// libs/core/src/components/spinner/gds-spinner.styles.ts
import { css } from "lit";
var styles = css`
  /* Host configuration with core variables */
  :host {
    /* Size variables with indexed access using CSS custom properties */
    --spinner-sizes: 2rem 3.75rem 6rem;
    --spinner-size-sm: 2rem;
    --spinner-size-md: 3.75rem;
    --spinner-size-lg: 6rem;

    --track-widths: 0.1rem 0.2rem 0.3rem;
    --track-width-sm: 0.275rem;
    --track-width-md: 0.375rem;
    --track-width-lg: 0.375rem;

    /* Default to light mode as fallback */
    --spinner-track-color: var(--gds-color-l3-background-secondary);
    --spinner-active-color: var(--gds-color-l3-content-secondary);
    --spinner-label-color: currentColor;
    --spinner-backdrop-color: rgba(0, 0, 0, 0.8);

    --spinner-backdrop-blur: 2px;

    /* Base sizing, will be overridden by size-specific variables */
    --size: var(--spinner-size-md);
    --track-width: var(--track-width-md);

    /* Use CSS variable for color-scheme to avoid minification issues */
    --spinner-color-scheme: light dark;
    color-scheme: var(--spinner-color-scheme);

    display: block;
  }

  /* Size-specific host settings */
  :host([size='sm']) {
    --size: var(--spinner-size-sm);
    --track-width: var(--track-width-sm);
  }

  :host([size='md']),
  :host([size='default']) {
    --size: var(--spinner-size-md);
    --track-width: var(--track-width-md);
  }

  :host([size='lg']) {
    --size: var(--spinner-size-lg);
    --track-width: var(--track-width-lg);
  }

  /* Fullscreen positioning */
  :host([fullscreen]) {
    position: fixed;
    inset: 0;
    width: 100vw;
    height: 100vh;
    z-index: 9999;
  }

  /* Focus styles */
  :host(:focus-visible) {
    outline: 2px solid var(--spinner-active-color);
    outline-offset: 2px;
  }

  /* Spinner component */
  .gds-spinner {
    border-radius: 50%;
    border: var(--track-width, 0.375rem) solid var(--spinner-track-color);
    border-top-color: var(--spinner-active-color);
    height: var(--size, 3.75rem);
    width: var(--size, 3.75rem);
    animation: gdsSpinnerRotation 1s linear infinite;
  }

  /* Motion preference adjustments */
  @media (prefers-reduced-motion: reduce) {
    .gds-spinner {
      /* Slower rotation for reduced motion preference */
      animation-duration: 2s;
      /* Smaller rotation to reduce visual intensity */
      animation-name: gdsSpinnerReducedRotation;
    }

    @keyframes gdsSpinnerReducedRotation {
      to {
        transform: rotate(180deg);
      }
    }
  }

  /* Layout components */
  .gds-spinner-wrapper {
    display: flex;
    justify-content: center;
    align-items: center;
    flex-direction: column;
  }

  .gds-spinner-wrapper.gds-spinner-cover {
    position: absolute;
    inset: 0;
    z-index: 999;
  }

  .gds-spinner-wrapper.gds-spinner-fullscreen {
    position: fixed;
    inset: 0;
    z-index: 9999;
  }

  .gds-spinner-wrapper.gds-spinner-backdrop {
    background-color: var(--spinner-backdrop-color);
    backdrop-filter: blur(var(--spinner-backdrop-blur));
    --spinner-label-color: #fff;
    --spinner-track-color: var(--gds-color-l3-content-secondary);
    --spinner-active-color: var(--gds-color-l3-background-secondary);
  }

  /* Label styling */
  .spinner-label {
    margin-top: 1rem;
    color: var(--spinner-label-color);
    text-align: center;
  }

  /* Animation keyframes */
  @keyframes gdsSpinnerRotation {
    to {
      transform: rotate(360deg);
    }
  }
`;

// libs/core/src/components/spinner/gds-spinner.ts
var _getWrapperClasses, getWrapperClasses_fn, _originalStyles;
var GdsSpinner = class extends withMarginProps(
  withPositioningProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super(...arguments);
    /**
     * Generates CSS classes for the wrapper element based on component state
     * @private
     */
    __privateAdd(this, _getWrapperClasses);
    this.label = msg("Loading...");
    this.showLabel = false;
    this.cover = false;
    this.fullscreen = false;
    this.size = "md";
    this._isAnimating = false;
    /**
     * Stores original document styles before applying fullscreen mode
     * @private
     */
    __privateAdd(this, _originalStyles, {
      overflow: "visible",
      overscrollBehavior: "auto"
    });
  }
  /**
   * Sets up accessibility attributes and initializes the spinner
   */
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "status");
    this.setAttribute("aria-live", "polite");
    this._isAnimating = true;
    this.dispatchEvent(new CustomEvent("gds-spinner-connected"));
  }
  /**
   * Cleans up document styles if fullscreen mode was used
   */
  disconnectedCallback() {
    super.disconnectedCallback();
    if (this.fullscreen) {
      this.fullscreen = false;
      this._toggleRootStyles();
    }
    this._isAnimating = false;
    super.disconnectedCallback();
  }
  _updateAriaLabel() {
    this.setAttribute("aria-label", this.label);
  }
  /**
   * Renders the spinner component
   */
  render() {
    return html`
      <div part="wrapper" class=${classMap(__privateMethod(this, _getWrapperClasses, getWrapperClasses_fn).call(this))}>
        <span part="spinner" class="gds-spinner"></span>
        ${when(
      this.label && this.showLabel,
      () => html`<span part="label" class="spinner-label">${this.label}</span>`,
      () => null
    )}
      </div>
    `;
  }
  _toggleRootStyles() {
    const { style } = document.documentElement;
    if (this.fullscreen) {
      __privateSet(this, _originalStyles, {
        overflow: style.overflow,
        overscrollBehavior: style.overscrollBehavior
      });
      style.overflow = "hidden";
      style.overscrollBehavior = "none";
    } else {
      style.overflow = __privateGet(this, _originalStyles).overflow;
      style.overscrollBehavior = __privateGet(this, _originalStyles).overscrollBehavior;
    }
  }
};
_getWrapperClasses = new WeakSet();
getWrapperClasses_fn = function() {
  return {
    "gds-spinner-wrapper": true,
    "gds-spinner-fullscreen": this.fullscreen,
    "gds-spinner-cover": this.cover,
    "gds-spinner-backdrop": this.cover || this.fullscreen,
    "gds-spinner-animating": this._isAnimating
  };
};
_originalStyles = new WeakMap();
/** All styles are defined in the external styles file */
GdsSpinner.styles = [tokens, styles];
__decorateClass([
  property({ type: String })
], GdsSpinner.prototype, "label", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "showLabel", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "cover", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "fullscreen", 2);
__decorateClass([
  property({ type: String, reflect: true })
], GdsSpinner.prototype, "size", 2);
__decorateClass([
  state()
], GdsSpinner.prototype, "_isAnimating", 2);
__decorateClass([
  watch("label")
], GdsSpinner.prototype, "_updateAriaLabel", 1);
__decorateClass([
  watch("fullscreen")
], GdsSpinner.prototype, "_toggleRootStyles", 1);
GdsSpinner = __decorateClass([
  gdsCustomElement("gds-spinner"),
  localized()
], GdsSpinner);

export {
  GdsSpinner
};
