// libs/core/src/utils/mixins/focusable.ts
var Focusable = (superClass) => {
  class HighlightableElement extends superClass {
    constructor() {
      super(...arguments);
      this.onblur = (e) => {
        this.setAttribute("tabindex", "-1");
        this.dispatchEvent(
          new FocusEvent("gds-blur", {
            bubbles: true,
            composed: true,
            relatedTarget: e.relatedTarget
          })
        );
      };
      this.onfocus = (e) => {
        this.dispatchEvent(
          new FocusEvent("gds-focus", {
            bubbles: true,
            composed: true,
            relatedTarget: e.relatedTarget
          })
        );
      };
    }
    focus(options) {
      this.setAttribute("tabindex", "0");
      super.focus(options);
    }
  }
  return HighlightableElement;
};

// libs/core/src/primitives/listbox/option.styles.ts
import { css } from "lit";
var style = css`
  @layer base, reset;

  @layer base {
    :host(:not(:last-child)) {
      border-bottom: 1px solid var(--gds-color-l2-border-primary);
    }

    :host div {
      display: flex;
      align-items: center;
      user-select: none;
      padding-inline: var(--gds-space-m);
      padding-block: var(--gds-space-m);
      cursor: pointer;
      font-size: var(--gds-text-size-label-input-large);
      font-weight: var(--gds-text-weight-regular);
      line-height: var(--gds-text-line-height-label-input-large);
      gap: 1ch;
      max-width: 100%;
      box-sizing: border-box;
      position: relative;

      &::before {
        content: ' ';
        display: flex;
        inset: var(--gds-space-2xs);
        position: absolute;
        border: var(--gds-space-3xs) solid currentColor;
        border-radius: var(--gds-space-xs);
        opacity: 0;
        visitility: hidden;
        pointer-events: none;
      }
    }

    :host([highlighted]) {
      background-color: var(--gds-color-l2-background-tertiary);
      color: var(--gds-color-l2-content-tertiary);
    }

    :host(:hover:not([highlighted])) div {
      background-color: var(--gds-color-l3-background-secondary);
    }

    :host(:focus-visible) {
      outline: none;

      div::before {
        inset: var(--gds-space-2xs);
        opacity: 1;
        visivility: visible;
      }
    }

    :host([aria-hidden='true']) {
      display: none;
    }

    .checkbox {
      display: flex;
      align-items: center;
      justify-content: center;
      height: 1lh;
      width: 1lh;
      box-sizing: border-box;
      position: relative;
      aspect-ratio: 1/1;
      border-radius: var(--gds-space-2xs);
      border: var(--gds-space-3xs) solid currentColor;
      padding: var(--gds-space-3xs);

      &.checked {
        background-color: currentColor;

        gds-icon-checkmark {
          &::part(icon) {
            color: var(--gds-color-l2-content-tertiary);
            stroke-width: var(--gds-space-2xs);
          }
        }
      }
    }
  }
`;
var option_styles_default = style;

export {
  Focusable,
  option_styles_default
};
