import { GdsElement } from '../../gds-element';
import { GdsColorLevel } from '../../utils/helpers';
declare const GdsDiv_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeXProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeYProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").MarginProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").PaddingProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").PositioningProps) & typeof GdsElement;
/**
 * @element gds-div
 * @status beta
 *
 * `gds-div` is the base element in the declarative layout system.
 */
export declare class GdsDiv extends GdsDiv_base {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the display property.
     * Supports all valid CSS display values.
     */
    display?: string;
    /**
     * The level of the container is used to resolve the color tokens from the corresponding level.
     * Check the [Color System documentation page](./?path=/docs/style-colors--docs) for more information.
     *
     * Default for `gds-div` is level 2.
     *
     */
    level: GdsColorLevel;
    /**
     * Style Expression Property that controls the `color` property.
     * Only accepts color tokens and an optional transparency value, in the format tokenName/transparency.
     *
     * ```html
     * <gds-div color="primary/0.2"></gds-div>
     * ```
     */
    color?: string;
    /**
     * Style Expression Property that controls the `background` property.
     * Only accepts color tokens and an optional transparency value, in the format tokenName/transparency.
     *
     * ```html
     * <gds-div background="primary/0.2"></gds-div>
     * ```
     */
    background?: string;
    /**
     * Style Expression Property that controls the `border` property.
     * Accepts a string of the same format as the CSS border property.
     *
     * ```html
     * <gds-div border="4xs solid primary/0.2"></gds-div>
     * ```
     *
     * Where the size value accepts space tokens and the color value accepts color tokens and an optional transparency value.
     */
    border?: string;
    /**
     * Style Expression Property that controls the `border-color` property.
     * Only accepts color tokens and an optional transparency value, in the format tokenName/transparency.
     *
     * ```html
     * <gds-div border-color="primary/0.2"></gds-div>
     * ```
     */
    'border-color'?: string;
    /**
     * Style Expression Property that controls the `border-width` property.
     * Only accepts space tokens.
     */
    'border-width'?: string;
    /**
     * Style Expression Property that controls the `border-style` property.
     * Supports all valid CSS `border-style` values.
     */
    'border-style'?: string;
    /**
     * Style Expression Property that controls the `border-radius` property.
     * Only accepts space tokens.
     */
    'border-radius'?: string;
    /**
     * Style Expression Property for the `box-shadow` property.
     *
     * Accepts shadow tokens from the design system.
     *
     * `xs`, `s`, `m`, `l`, `xl`
     */
    'box-shadow'?: string;
    /**
     * Style Expression Property that controls the `opacity` property.
     * Supports all valid CSS `opacity` values.
     */
    opacity?: string;
    /**
     * Style Expression Property that controls the `overflow` property.
     * Supports all valid CSS `overflow` values.
     */
    overflow?: string;
    /**
     * Style Expression Property that controls the `box-sizing` property.
     * Supports all valid CSS `box-sizing` values.
     */
    'box-sizing'?: string;
    /**
     * Style Expression Property that controls the `z-index` property.
     * Supports all valid CSS `z-index` values.
     */
    'z-index'?: string;
    /**
     * Style Expression Property that controls the `font-size` property.
     * Supports all typography size tokens from the design system.
     */
    'font-size'?: string;
    /**
     * Style Expression Property that controls the `font-weight` property.
     * Supports all typography weight tokens from the design system.
     */
    'font-weight'?: string;
    /**
     * Style Expression Property that controls the `text-align` property.
     * Supports all valid CSS `text-align` values.
     */
    'text-align'?: string;
    /**
     * Style Expression Property that controls the `text-wrap` property.
     * Supports all valid CSS `text-wrap` values.
     */
    'text-wrap'?: string;
    /**
     * Style Expression Property that controls the `gap` property.
     * Only accepts space tokens.
     */
    gap?: string;
    /**
     * Style Expression Property that controls the `align-items` property.
     * Supports all valid CSS `align-items` values.
     */
    'align-items'?: string;
    /**
     * Style Expression Property that controls the `align-content` property.
     * Supports all valid CSS `align-content` values.
     */
    'align-content'?: string;
    /**
     * Style Expression Property that controls the `justify-content` property.
     * Supports all valid CSS `justify-content` values.
     */
    'justify-content'?: string;
    /**
     * Style Expression Property that controls the `justify-items` property.
     * Supports all valid CSS `justify-items` values.
     */
    'justify-items'?: string;
    /**
     * Style Expression Property that controls the `flex-direction` property.
     * Supports all valid CSS `flex-direction` values.
     */
    'flex-direction'?: string;
    /**
     * Style Expression Property that controls the `flex-wrap` property.
     * Supports all valid CSS `flex-wrap` values.
     */
    'flex-wrap'?: string;
    /**
     * Style Expression Property that controls the `place-items` property.
     * Supports all valid CSS `place-items` values.
     */
    'place-items'?: string;
    /**
     * Style Expression Property that controls the `place-content` property.
     * Supports all valid CSS `place-content` values.
     */
    'place-content'?: string;
    render(): any;
}
export {};
