import { GdsElement } from '../../gds-element';
/**
 * @element gds-divider
 * @status beta
 *
 * The `gds-divider` component is a horizontal rule that separates content in a layout. It is equivalent to the `<hr>` element in HTML, and provides the same semantic meaning.
 */
export declare class GdsDivider extends GdsElement {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The level of the divider is used to resolve the color tokens from the corresponding level.
     * Check the [Color System documentation page](./?path=/docs/style-colors--docs) for more information.
     *
     * Default value for `gds-divider` is set to `2`.
     *
     * @property level
     *
     * */
    level: string;
    /**
     * Controls the color property of the divider.
     * Supports all the color tokens from the design system.
     *
     * You can apply color like this:
     *
     * ```html
     * <gds-divider color="primary"></gds-divider>
     * ```
     */
    color?: string;
    /**
     * Controls the size property of the divider.
     * Supports all the space tokens from the design system.
     *
     * You can apply size like this:
     *
     * ```html
     * <gds-divider size="2xl"></gds-divider>
     * ```
     *
     * The above example will apply the size style of 2xl.
     *
     */
    size?: string;
    /**
     * Controls the opacity property of the divider.
     * Supports all the opacity tokens from the design system.
     *
     * You can apply opacity like this:
     *
     * ```html
     * <gds-divider opacity="0.2"></gds-divider>
     * ```
     * The above example will apply the opacity style of base400.
     *
     */
    opacity?: string;
    /**
     * Use the role attribute primarily if you only want the divider to be a visual element.
     *
     * ```html
     * <!-- This divider will not be announced as a separator or thematic break -->
     * <gds-divider role="presentation"></gds-divider>
     * ```
     */
    role: string | null;
    render(): any;
}
