import { GdsElement } from '../../gds-element';
declare const GdsImg_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").PositioningProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeXProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeYProps) & typeof GdsElement;
/**
 * @element gds-img
 * @status beta
 *
 * `gds-img` is a custom element that make it possible to use some Style Expression Properties to style images.
 */
export declare class GdsImg extends GdsImg_base {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the aspect ratio of the image.
     * Supports all common aspect ratios like 16/9, 4/3, 1/1, etc.
     *
     * You can apply the aspect ratio like this:
     * ```html
     * <gds-img aspect-ratio="16/9"></gds-img>
     * ```
     * The above example will apply the aspect ratio of 16/9.
     *
     * You can also apply different aspect ratios for different screen sizes like this:
     * ```html
     * <gds-img aspect-ratio="l{16/9} m{4/3} s{1/1}"></gds-img>
     * ```
     *
     * The above example will apply the aspect ratio of 16/9 for large screens, 4/3 for medium screens, and 1/1 for small screens.
     */
    'aspect-ratio'?: string;
    /**
     * Controls the border-radius property of the image.
     * Supports all the size tokens from the design system.
     *
     * You can apply radius in each corner like this:
     * ```html
     * <gds-img border-radius="none none m m" ></gds-img>
     * ```
     *
     * Also for different breakpoints like this:
     * ```html
     * <gds-img border-radius="s{xs} m{xs} l{s}"></gds-img>
     * ```
     */
    'border-radius'?: string;
    /**
     * Controls the object-fit property of the image.
     *
     * You can apply fit like this:
     * ```html
     * <gds-img object-fit="cover"></gds-img>
     * ```
     *
     *  The above example will apply the object-fit style of cover.
     *
     * @property fit
     */
    'object-fit'?: string;
    /**
     * Controls the `object-position` of the img.
     * Supports all common CSS values.
     * @property position
     */
    'object-position'?: string;
    /**
     * The image source URL.
     *
     * @property src
     */
    src?: string;
    /**
     * The image alt text.
     *
     * @property alt
     */
    alt?: string;
    render(): any;
}
export {};
