import { GdsElement } from '../../gds-element';
declare const GdsRichText_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").MarginProps) & typeof GdsElement;
/**
 * `gds-rich-text` can be used to wrap generic HTML content and apply typography styles.
 *
 * The wrapped content will render inside the shadowRoot of the `gds-rich-text` element, thereby applying the
 * default typography styles and standard element styles defined in the Green Design System.
 *
 * @element gds-rich-text
 * @status beta
 *
 */
export declare class GdsRichText extends GdsRichText_base {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Capture mode for the content.
     *
     * - `clone` (default): Clones the content to the shadowRoot.\
     *   This is the default and most compatible behaviour, since it leaves the original DOM untouched.
     *   the downside is that events added through `addEventListener` will not be retained in the cloned DOM.
     *
     * - `move`: Moves the content to the inner shadowRoot.\
     *   This mode moves the full original sub-tree into the shadowRoot, leaving everything, including event
     *   listeners, intact.
     *   This mode is less compatible with some libraries that rely on the original DOM structure, for example React
     */
    captureMode: 'clone' | 'move';
    /**
     * Forwards the selector to the corresponding function on the inner shadowRoot.
     */
    querySelectorAll(selector: string): NodeList;
    /**
     * Forwards the selector to the corresponding function on the inner shadowRoot.
     */
    querySelector(selector: string): Element | null;
    /**
     * Forwards innerHTML from the inner shadowRoot.
     */
    get innerHTML(): string;
    set innerHTML(value: string);
    connectedCallback(): void;
    private _captureDOM;
}
export {};
