import { GdsFormControlElement } from '../form/form-control';
import type { GdsButton } from '../button';
import '../../primitives/form-control-header';
import '../../primitives/form-control-footer';
import '../../primitives/field-base';
import '../icon/icons/cross-large';
import '../button';
declare class Textarea extends GdsFormControlElement<string> {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    private _initialRows?;
    private _defaultRows;
    /**
     * Rows of the textarea
     */
    rows: number;
    /**
     * The supporting text displayed between the label and the field itself
     */
    supportingText: string;
    /**
     * Whether the field should be clearable or not. Clearable fields will display a clear button when
     * the field has a value.
     */
    clearable: boolean;
    /**
     * The resizable attribute of the textarea. It can be set to 'auto', 'manual' or 'false'.
     * When set to 'auto', the textarea will be resizable in the vertical direction based on content.
     * When set to 'manual', the textarea will be resizable in both the vertical and horizontal directions.
     * When set to 'false', the textarea will not be resizable.
     */
    resizable: 'auto' | 'manual' | 'false';
    /**
     * The maximum number of characters allowed in the field.
     */
    maxlength: number;
    /**
     * The variant of the input field. The default variant displays a label, supporting text, and
     * extended supporting text. The floating-label variant only displays the field itself and the
     * supporting text below.
     *
     * The floating-label variant should only be used in specific cases, for example when the input field
     * is placed inside a table cell or in a space-constrained layout.
     *
     * A typical form should use the default variant.
     */
    variant: 'default' | 'floating-label';
    /**
     * Controls the font-size of texts.
     */
    size: 'large' | 'small';
    private elTextareaAsync;
    private elTextarea;
    private fieldBase;
    /**
     * A reference to the clear button element. Returns null if there is no clear button.
     * Intended for use in integration tests.
     */
    test_getClearButton(): GdsButton | null | undefined;
    /**
     * A reference to the field element. This does not refer to the input element itself,
     * but the wrapper that makes up the visual field.
     * Intended for use in integration tests.
     */
    test_getFieldElement(): Element | null | undefined;
    private _handleResize;
    private _handleSlotChange;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    render(): any;
    protected _getValidityAnchor(): HTMLTextAreaElement;
    private _setAutoHeight;
    private _handleRowsChange;
}
declare const GdsTextarea_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeXProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").MarginProps) & typeof Textarea;
/**
 * @summary A custom input element that can be used in forms.
 * @status beta
 *
 * @element gds-textarea
 *.
 * @slot lead - Accepts `gds-icon-[ICON_NAME]`. Use this to place an icon in the start of the field.
 * @slot trail - Accepts `gds-badge`. Use this to place a badge in the field, for displaying currency for example.
 * @slot extended-supporting-text - A longer supporting text can be placed here. It will be
 *       displayed in a panel when the user clicks the info button.
 * @event gds-input-cleared - Fired when the clear button is clicked.
 */
export declare class GdsTextarea extends GdsTextarea_base {
}
export {};
